window.Gleam.initSearch([{"doc":"gleamsver","title":"gleamsver","content":"# gleamsver\n\nComprehensive set of native Gleam utilities for handling\n[SemVer 2.0.0](https://semver.org) version strings.\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamsver)](https://hex.pm/packages/gleamsver)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamsver/)\n\n```sh\ngleam add gleamsver\n```\n\n```gleam\nimport gleam/io\nimport gleamsver\n\nfn compress_message(message: String) -&gt; String {\n  message &lt;&gt; &quot;, but compressed ;)&quot;\n}\n\npub fn main() {\n  // Parse correct SemVer 2.0.0 strings using `parse()`:\n  let assert Ok(server_version_with_compression) = gleamsver.parse(&quot;1.3.7-rc0&quot;)\n  io.debug(server_version_with_compression)  // SemVer(1, 3, 7, &quot;rc0&quot;, &quot;&quot;)\n\n  // Parse loose SemVer strings using `parse_loosely()`:\n  let assert Ok(current_server_version) = gleamsver.parse_loosely(&quot;v1.4&quot;)\n\n  // Convert back to SemVer strings using `to_string()`:\n  let uncompressed_message =\n    &quot;Hello, server version &quot; &lt;&gt; gleamsver.to_string(current_server_version)\n\n  let message = {\n    // Guard against version mismatches using `guard_version_*()` functions:\n    use &lt;- gleamsver.guard_version_compatible(\n      version: server_version_with_compression,\n      compatible_with: current_server_version,\n      else_return: uncompressed_message,\n    )\n\n    // Compression will only occur if the above guard succeeds:\n    compress_message(uncompressed_message)\n  }\n\n  // Prints &quot;Hello, server version 1.4.0, but compressed ;)&quot;\n  io.println(message)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleamsver&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"gleamsver","title":"SemVer","content":"pub type SemVer {\n  SemVer(\n    major: Int,\n    minor: Int,\n    patch: Int,\n    pre: String,\n    build: String,\n  )\n}\n SemVer represents all the constituent parts of a Semantic Versioning\n (or SemVer) 2.0.0 definition as described on [semver.org](https://semver.org).\nSemVer(\n  major: Int,\n  minor: Int,\n  patch: Int,\n  pre: String,\n  build: String,\n)\n\nmajor\n&lt;p&gt;Leading Major Integer version.&lt;/p&gt;\n\nminor\n&lt;p&gt;Middle Minor Integer version.&lt;/p&gt;\n\npatch\n&lt;p&gt;Third Patch Integer version.&lt;/p&gt;\n\npre\n&lt;p&gt;String Pre-build tag(s) of the version.&lt;/p&gt;\n\nbuild\n&lt;p&gt;String Build tag(s) of the version.&lt;/p&gt;\n\nSynonyms:\ngleamsver.SemVer\ngleamsver SemVer","url":"gleamsver.html#SemVer"},{"doc":"gleamsver","title":"SemVerParseError","content":"pub type SemVerParseError {\n  EmptyInput(msg: String)\n  MissingMajor(msg: String)\n  MissingMinor(msg: String)\n  MissingPatch(msg: String)\n  MissingPreRelease(msg: String)\n  MissingBuild(msg: String)\n  MissingPreOrBuildSeparator(msg: String)\n  InvalidMajor(msg: String)\n  InvalidMinor(msg: String)\n  InvalidPatch(msg: String)\n  InvalidPreRelease(msg: String)\n  InvalidBuild(msg: String)\n  InternalCodePointError(msg: String)\n  InternalError(msg: String)\n}\n Type whose variants can possibly be returned by [`parse`](#parse) on invalid\n inputs, and a subset of them can be returned by [`parse_loosely`](#parse_loosely).\n\n To get the error string from within it, simply use `the_error.msg`,\n or call [`string_from_parsing_error(the_error)`](#string_from_parsing_error).\n\nEmptyInput(msg: String)\n Returned only by [`parse`](#parse) when its input is empty.\n\nMissingMajor(msg: String)\n Returned when the Major part of a [`SemVer`](#SemVer) is missing.\n I.e. there are no leading numeric digits to the input String.\n\nMissingMinor(msg: String)\n Returned only by [`parse`](#parse) when the Minor part of a [`SemVer`](#SemVer) is missing.\n I.e. when there is no Minor part like `1..3` or `1-pre+build`.\n\nMissingPatch(msg: String)\n Returned only by [`parse`](#parse) when the Patch part of a [`SemVer`](#SemVer) is missing.\n I.e. when there is no Patch part like `1.2.+build` or `1.2-pre+build`.\n\nMissingPreRelease(msg: String)\n Returned only by [`parse`](#parse) when the Pre-release part of a [`SemVer`](#SemVer)\n is missing despite it having its leading hyphen present.\n E.g: `1.2.3-` or `1.2.3-+build`.\n\nMissingBuild(msg: String)\n Returned only by [`parse`](#parse) when the Build part of a [`SemVer`](#SemVer)\n is missing despite it having its leading plus present.\n E.g: `1.2.3+` or `1.2.3-rc0+`.\n\nMissingPreOrBuildSeparator(msg: String)\n Returned when there is no Pre-release or Build separators (`-` and `+`)\n between the Major.Minor.Patch core part of the [`SemVer`](#SemVer) and the rest.\n E.g: `1.2.3rc0` or `1.2.3build5`.\n\nInvalidMajor(msg: String)\n Returned when the Integer Major part of a [`SemVer`](#SemVer) cannot be parsed.\n\nInvalidMinor(msg: String)\n Returned when the Integer Minor part of a [`SemVer`](#SemVer) cannot be parsed.\n\nInvalidPatch(msg: String)\n Returned when the Integer Patch part of a [`SemVer`](#SemVer) cannot be parsed.\n\nInvalidPreRelease(msg: String)\n Returned only by [`parse`](#parse) when the Pre-release tag part\n of a [`SemVer`](#SemVer) contains unacceptable characters.\n\nInvalidBuild(msg: String)\n Returned only by [`parse`](#parse) when the Build tag part\n of a [`SemVer`](#SemVer) contains unacceptable characters.\n\nInternalCodePointError(msg: String)\n Internal UTF conversion error which you should **never** get.\n\nInternalError(msg: String)\n Internal error variant only used for testing which you should **never** get.\n\nSynonyms:\ngleamsver.SemVerParseError\ngleamsver SemVerParseError","url":"gleamsver.html#SemVerParseError"},{"doc":"gleamsver","title":"empty_semver","content":"pub const empty_semver: SemVer\n Constant representing an empty SemVer\n (`0.0.0` with no pre-release or build tags).\nSynonyms:\ngleamsver.empty_semver\ngleamsver empty_semver","url":"gleamsver.html#empty_semver"},{"doc":"gleamsver","title":"are_compatible","content":"pub fn are_compatible(v1: SemVer, with v2: SemVer) -&gt; Bool\n Checks whether the first given [`SemVer`](#SemVer) is compatible with\n the second based on the\n [compatibility rules described on semver.org](https://semver.org/#semantic-versioning-specification-semver).\n\n In order for a version to count as compatible with another, the Major part\n of the versions must be **exactly equal**, and the Minor, Patch and\n Pre-release parts of the first must be less than or equal to the second&#39;s.\n\n If you would like to compare versions in general, use [`compare`](#compare)\n or [compare_core](#compare_core).\n\n ## Examples\n\n \n are_compatible(SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;), SemVer(1, 2, 4, &quot;&quot;, &quot;&quot;))\n -&gt; True\n\n are_compatible(SemVer(2, 0, 0, &quot;&quot;, &quot;&quot;), SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;))\n -&gt; False\n\n // NOTE: Any Pre-release tags have lower precedence than full release:\n are_compatible(SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;), SemVer(1, 2, 3, &quot;alpha.1&quot;, &quot;&quot;))\n -&gt; False\n\n // NOTE: Build tags are **not** compared:\n are_compatible(SemVer(1, 2, 3, &quot;&quot;, &quot;20240505&quot;), SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;))\n -&gt; True\n \n\nSynonyms:\ngleamsver.are_compatible\ngleamsver are_compatible","url":"gleamsver.html#are_compatible"},{"doc":"gleamsver","title":"are_equal","content":"pub fn are_equal(v1: SemVer, with v2: SemVer) -&gt; Bool\n Compares the core `Major.Minor.Patch` and the Pre-release and Build tags\n of the two given [`SemVer`](#SemVer)s, returning `True` only if they\n are exactly equal.\n\n ## Examples\n\n \n are_equal(SemVer(1, 2, 3, &quot;rc5&quot;, &quot;&quot;), with: SemVer(1, 2, 3, &quot;rc5&quot;, &quot;&quot;))\n // -&gt; True\n\n // NOTE: Pre-release and Build parts must be exactly equal too!\n are_equal(SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;), with: SemVer(1, 2, 3, &quot;rc0&quot;, &quot;20250505&quot;))\n // -&gt; False\n \n\nSynonyms:\ngleamsver.are_equal\ngleamsver are_equal","url":"gleamsver.html#are_equal"},{"doc":"gleamsver","title":"are_equal_core","content":"pub fn are_equal_core(v1: SemVer, with v2: SemVer) -&gt; Bool\n Compares **only** the core `Major.Minor.Patch` of the two given\n [`SemVer`](#SemVer)s, returning `True` only if they are exactly equal.\n\n If you would like an exact equality check of the Pre-release and Build\n parts as well, please use [`are_equal`](#are_equal).\n\n ## Examples\n\n \n are_equal_core(SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;), with: SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;))\n // -&gt; True\n\n // NOTE: Pre-release and Build parts are **not** compared!\n are_equal_core(SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;), with: SemVer(1, 2, 3, &quot;rc0&quot;, &quot;20250505&quot;))\n // -&gt; True\n\n are_equal_core(SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;), with: SemVer(4, 5, 6, &quot;&quot;, &quot;&quot;))\n // -&gt; False\n \n\nSynonyms:\ngleamsver.are_equal_core\ngleamsver are_equal_core","url":"gleamsver.html#are_equal_core"},{"doc":"gleamsver","title":"compare","content":"pub fn compare(v1: SemVer, with v2: SemVer) -&gt; Order\n Compares the core `Major.Minor.Patch` versions and Pre-release tags of the\n two given [`SemVer`](#SemVer)s, returning the `gleam/order.Order` of the resulting\n comparisons as described on [semver.org](https://semver.org/#spec-item-11).\n\n If you would like to only compare core versions, use\n [`compare_core`](#compare_core).\n\n If you want to check for exact equality, use [`are_equal`](#are_equal).\n\n Build tag(s) are **never** compared.\n\n ## Examples:\n\n \n compare(SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;), with: SemVer(5, 6, 7, &quot;&quot;, &quot;&quot;))\n // -&gt; Lt\n\n compare(SemVer(1, 2, 3, &quot;rc0&quot;, &quot;&quot;), with: SemVer(1, 2, 3, &quot;rc0&quot;, &quot;&quot;))\n // -&gt; Eq\n\n compare(SemVer(5, 6, 7, &quot;rc0&quot;, &quot;20240505&quot;), with: SemVer(1, 2, 3, &quot;rc5&quot;, &quot;30240505&quot;))\n // -&gt; Gt\n\n // NOTE: pre-release tags are compared:\n compare(SemVer(1, 2, 3, &quot;alpha&quot;, &quot;&quot;), with: SemVer(1, 2, 3, &quot;alpha.1&quot;, &quot;&quot;))\n // -&gt; Lt\n\n compare(SemVer(1, 2, 3, &quot;alpha.12&quot;, &quot;&quot;), with: SemVer(1, 2, 3, &quot;alpha.5&quot;, &quot;&quot;))\n // -&gt; Gt\n\n // NOTE: will **not** compare Build tags at all!\n compare(SemVer(1, 2, 3, &quot;rc5&quot;, &quot;20240505&quot;), with: SemVer(1, 2, 3, &quot;rc5&quot;, &quot;30240505&quot;))\n // -&gt; Eq\n \n\nSynonyms:\ngleamsver.compare\ngleamsver compare","url":"gleamsver.html#compare"},{"doc":"gleamsver","title":"compare_core","content":"pub fn compare_core(v1: SemVer, with v2: SemVer) -&gt; Order\n Compares **only** the core `Major.Minor.Patch` versions of the two given\n [`SemVer`](#SemVer)s, returning the `gleam/order.Order` of the resulting\n comparisons.\n\n It does **not** compare the Pre-release or Build tags in any way!\n\n If you would like to compare Pre-release tags too, use [`compare`](#compare).\n\n If you want to check for exact equality, use [`are_equal`](#are_equal).\n\n ## Examples:\n\n \n compare_core(SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;), with: SemVer(5, 6, 7, &quot;&quot;, &quot;&quot;))\n // -&gt; Lt\n\n compare_core(SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;), with: SemVer(1, 2, 3, &quot;&quot;, &quot;&quot;))\n // -&gt; Eq\n\n compare_core(SemVer(5, 6, 7, &quot;rc0&quot;, &quot;20240505&quot;), with: SemVer(1, 2, 3, &quot;rc5&quot;, &quot;30240505&quot;))\n // -&gt; Gt\n\n // NOTE: will **not** compare Pre-release and Build tags at all!\n compare_core(SemVer(1, 2, 3, &quot;rc0&quot;, &quot;20240505&quot;), with: SemVer(1, 2, 3, &quot;rc5&quot;, &quot;30240505&quot;))\n // -&gt; Eq\n \n\nSynonyms:\ngleamsver.compare_core\ngleamsver compare_core","url":"gleamsver.html#compare_core"},{"doc":"gleamsver","title":"compare_pre_release_strings","content":"pub fn compare_pre_release_strings(\n  pre1: String,\n  with pre2: String,\n) -&gt; Order\n Compares two given pre-release Strings based on the set of\n rules described in [point 11 of semver.org](https://semver.org/#spec-item-11).\n\n ## Examples.\n\n \n // NOTE: empty pre-release tags always count as larger:\n compare_pre_release_strings(&quot;&quot;, &quot;any.thing&quot;)\n // -&gt; Gt\n\n compare_pre_release_strings(&quot;any.thing&quot;, &quot;&quot;)\n // -&gt; Lt\n\n // Integer parts are compared as integers:\n compare_pre_release_strings(&quot;12.thing.A&quot;, &quot;13.thing.B&quot;)\n // -&gt; Lt\n\n // Non-integer parts are compared lexicographically:\n compare_pre_release_strings(&quot;12.thing.A&quot;, &quot;12.thing.B&quot;)\n // -&gt; Lt\n\n // NOTE: integer parts always have lower precedence over non-integer ones:\n compare_pre_release_strings(&quot;12.thing.1&quot;, &quot;12.thing.rc0&quot;)\n // -&gt; Lt\n\n // NOTE: &#39;B&#39; comes before &#39;a&#39; in the ASCII table:\n compare_pre_release_strings(&quot;12.thing.B&quot;, &quot;12.thing.a&quot;)\n // -&gt; Lt\n\n // NOTE: &#39;0&#39; comes before &#39;6&#39; in the ASCII table:\n compare_pre_release_strings(&quot;rc07&quot;, &quot;rc6&quot;)\n // -&gt; Lt\n \n\nSynonyms:\ngleamsver.compare_pre_release_strings\ngleamsver compare_pre_release_strings","url":"gleamsver.html#compare_pre_release_strings"},{"doc":"gleamsver","title":"guard_version_compatible","content":"pub fn guard_version_compatible(\n  version v1: SemVer,\n  compatible_with v2: SemVer,\n  else_return default_value: a,\n  if_compatible operation_if_compatible: fn() -&gt; a,\n) -&gt; a\n Guards that the given first [`SemVer`](#SemVer) is compatible with\n the second [`SemVer`](#SemVer), running and returning the result\n of the `if_compatible` callback function if so,\n or returning the `else_return` value if not.\n\n The semantics of the compatibility check are as dictated by the\n [`are_compatible`](#are_compatible) function.\n\n ## Examples\n\n \n let uncompressed_message = &quot;Hello!&quot;\n let message = {\n   use &lt;- gleamsver.guard_version_compatible(\n     version: server_version_with_compression,\n     compatible_with: current_server_version,\n     else_return: uncompressed_message,\n   )\n\n   // Compression will only occur if the above guard succeeds:\n   uncompressed_message &lt;&gt; &quot;, but compressed ;)&quot;\n }\n io.println(message)  // compression depends on version compatibility\n \nSynonyms:\ngleamsver.guard_version_compatible\ngleamsver guard_version_compatible","url":"gleamsver.html#guard_version_compatible"},{"doc":"gleamsver","title":"guard_version_eq","content":"pub fn guard_version_eq(\n  version v1: SemVer,\n  equal_to v2: SemVer,\n  else_return default_value: a,\n  if_compatible operation_if_eq: fn() -&gt; a,\n) -&gt; a\n Guards that the given first [`SemVer`](#SemVer) is equal to\n the second [`SemVer`](#SemVer), running and returning the\n result of the `if_compatible` callback function if so, or\n returning the `else_return` default value if not.\n\n The semantics of the comparison check are as dictated by the\n [`compare`](#compare) function.\n\n ## Examples\n\n \n let uncompressed_message = &quot;Hello!&quot;\n let message = {\n   use &lt;- gleamsver.guard_version_eq(\n     version: server_version_with_compression,\n     equal_to: current_server_version,\n     else_return: uncompressed_message,\n   )\n\n   // Compression will only occur if the above guard succeeds:\n   uncompressed_message &lt;&gt; &quot;, but compressed ;)&quot;\n }\n io.println(message)  // compression depends on version equality\n \nSynonyms:\ngleamsver.guard_version_eq\ngleamsver guard_version_eq","url":"gleamsver.html#guard_version_eq"},{"doc":"gleamsver","title":"guard_version_gt","content":"pub fn guard_version_gt(\n  version v1: SemVer,\n  greater_than v2: SemVer,\n  else_return default_value: a,\n  if_compatible operation_if_gt: fn() -&gt; a,\n) -&gt; a\n Guards that the given first [`SemVer`](#SemVer) is greater than\n the second [`SemVer`](#SemVer), running and returning the result\n of the `if_compatible` callback function if so, or\n returning the `else_return` default value if not.\n\n The semantics of the comparison check are as dictated by the\n [`compare`](#compare) function.\n\n ## Examples\n\n \n let uncompressed_message = &quot;Hello!&quot;\n let message = {\n   use &lt;- gleamsver.guard_version_gt(\n     version: current_server_version,\n     greater_than: server_version_with_compression,\n     else_return: uncompressed_message,\n   )\n\n   // Compression will only occur if the above guard succeeds:\n   uncompressed_message &lt;&gt; &quot;, but compressed ;)&quot;\n }\n io.println(message)  // compression depends on version ordering\n \nSynonyms:\ngleamsver.guard_version_gt\ngleamsver guard_version_gt","url":"gleamsver.html#guard_version_gt"},{"doc":"gleamsver","title":"guard_version_gte","content":"pub fn guard_version_gte(\n  version v1: SemVer,\n  greater_than_or_equal v2: SemVer,\n  else_return default_value: a,\n  if_compatible operation_if_gte: fn() -&gt; a,\n) -&gt; a\n Guards that the given first [`SemVer`](#SemVer) is greater than\n or equal to the second [`SemVer`](#SemVer), running and returning\n the result of the `if_compatible` callback function if so, or\n returning the `else_return` default value if not.\n\n The semantics of the comparison check are as dictated by the\n [`compare`](#compare) function.\n\n ## Examples\n\n \n let uncompressed_message = &quot;Hello!&quot;\n let message = {\n   use &lt;- gleamsver.guard_version_gte(\n     version: current_server_version,\n     greater_than_or_equal: server_version_with_compression,\n     else_return: uncompressed_message,\n   )\n\n   // Compression will only occur if the above guard succeeds:\n   uncompressed_message &lt;&gt; &quot;, but compressed ;)&quot;\n }\n io.println(message)  // compression depends on version ordering\n \nSynonyms:\ngleamsver.guard_version_gte\ngleamsver guard_version_gte","url":"gleamsver.html#guard_version_gte"},{"doc":"gleamsver","title":"guard_version_lt","content":"pub fn guard_version_lt(\n  version v1: SemVer,\n  less_than v2: SemVer,\n  else_return default_value: a,\n  if_compatible operation_if_lt: fn() -&gt; a,\n) -&gt; a\n Guards that the given first [`SemVer`](#SemVer) is less than\n the second [`SemVer`](#SemVer), running and returning the result\n of the `if_compatible` callback function if so, or\n returning the `else_return` default value if not.\n\n The semantics of the comparison check are as dictated by the\n [`compare`](#compare) function.\n\n ## Examples\n\n \n let uncompressed_message = &quot;Hello!&quot;\n let message = {\n   use &lt;- gleamsver.guard_version_lt(\n     version: server_version_with_compression,\n     less_that: current_server_version,\n     else_return: uncompressed_message,\n   )\n\n   // Compression will only occur if the above guard succeeds:\n   uncompressed_message &lt;&gt; &quot;, but compressed ;)&quot;\n }\n io.println(message)  // compression depends on version ordering\n \nSynonyms:\ngleamsver.guard_version_lt\ngleamsver guard_version_lt","url":"gleamsver.html#guard_version_lt"},{"doc":"gleamsver","title":"guard_version_lte","content":"pub fn guard_version_lte(\n  version v1: SemVer,\n  less_than_or_equal v2: SemVer,\n  else_return default_value: a,\n  if_compatible operation_if_lte: fn() -&gt; a,\n) -&gt; a\n Guards that the given first [`SemVer`](#SemVer) is less than or equal\n to the second [`SemVer`](#SemVer), running and returning the result\n of the `if_compatible` callback function if so, or\n returning the `else_return` default value if not.\n\n The semantics of the comparison check are as dictated by the\n [`compare`](#compare) function.\n\n ## Examples\n\n \n let uncompressed_message = &quot;Hello!&quot;\n let message = {\n   use &lt;- gleamsver.guard_version_lte(\n     version: server_version_with_compression,\n     less_that_or_equal: current_server_version,\n     else_return: uncompressed_message,\n   )\n\n   // Compression will only occur if the above guard succeeds:\n   uncompressed_message &lt;&gt; &quot;, but compressed ;)&quot;\n }\n io.println(message)  // compression depends on version ordering\n \nSynonyms:\ngleamsver.guard_version_lte\ngleamsver guard_version_lte","url":"gleamsver.html#guard_version_lte"},{"doc":"gleamsver","title":"parse","content":"pub fn parse(version: String) -&gt; Result(SemVer, SemVerParseError)\n Parses the given string into a [`SemVer`](#SemVer).\n\n Parsing rules are **exactly** based on the rules defined on [semver.org](https://semver.org).\n\n If you would prefer some leniency when parsing, see [`parse_loosely`](#parse_loosely).\n\n See [`SemVerParseError`](#SemVerParseError) for possible error variants\n returned by [`parse`](#parse).\n\n ## Examples\n\n \n parse(&quot;1.2.3-rc0+20240505&quot;)\n // -&gt; Ok(SemVer(major: 1, minor; 2, patch: 3, pre: &quot;rc0&quot;, build: &quot;20240505&quot;))\n \n\n Both the Pre-release (`-rc0`) and Build (`+20240505`) parts are optional:\n\n \n parse(&quot;4.5.6-rc0&quot;)\n // -&gt; Ok(SemVer(major: 4, minor; 5, patch: 6, pre: &quot;rc0&quot;, build: &quot;&quot;))\n\n parse(&quot;4.5.6+20240505&quot;)\n // -&gt; Ok(SemVer(major: 4, minor; 5, patch: 6, pre: &quot;&quot;, build: &quot;20240505&quot;))\n\n parse(&quot;4.5.6-rc0+20240505&quot;)\n // -&gt; Ok(SemVer(major: 4, minor; 5, patch: 6, pre: &quot;rc0&quot;, build: &quot;20240505&quot;))\n\n // NOTE: the Pre-release should always come *before* the Build,\n // otherwise, it will get included as part of the Build:\n parse(&quot;6.7.8+20240505-rc0&quot;)\n // -&gt; Ok(SemVer(major: 4, minor; 5, patch: 6, pre: &quot;&quot;, build: &quot;20240505-rc0&quot;))\n \n\n ## Possible parsing errors\n\n The [`parse`](#parse) function aims to return a relevant error variant\n and  accompanying helpful `String` message on parsing failures.\n\n Please see [`type SemVerParseError`](#SemVerParseError) and\n [`string_from_parsing_error`](#string_from_parsing_error).\n\n \n parse(&quot;abc&quot;)\n // -&gt; MissingMajor(&quot;Leading Major SemVer Integer part is missing.&quot;)\n // To get the error String directly, simply:\n parse(&quot;abc&quot;) |&gt; result.map_error(string_from_parsing_error)\n // -&gt; Error(&quot;Leading Major SemVer Integer part is missing.&quot;)\n \n\nSynonyms:\ngleamsver.parse\ngleamsver parse","url":"gleamsver.html#parse"},{"doc":"gleamsver","title":"parse_loosely","content":"pub fn parse_loosely(\n  version: String,\n) -&gt; Result(SemVer, SemVerParseError)\n Parse the given string into a [`SemVer`](#SemVer) more loosely than\n [`parse`](#parse).\n\n Please see [`parse`](#parse) for a baseline on how this function works, as\n all inputs accepted by [`parse`](#parse) are also accepted by\n [`parse_loosely`](#parse_loosely).\n\n The main additions over the behavior of [`parse`](#parse) are as follows:\n * will also accept a single leading `v` in the input (e.g. `v1.2.3-pre+build`)\n * will accept missing Minor and/or Patch versions (e.g. `1-pre+build`)\n * will accept *any* non-alphanumeric character in the Pre-release and Build\n   parts as long as they are still prefixed by the usual `-` or `+`.\n\n See [`SemVerParseError`](#SemVerParseError) for possible error variants\n returned by [`parse_loosely`](#parse_loosely).\n\n ## Examples\n\n \n parse_loosely(&quot;&quot;)\n // -&gt; Ok(SemVer(major: 0, minor; 0, patch: 0, pre: &quot;&quot;, build: &quot;&quot;))\n \n\n \n parse_loosely(&quot;v1-rc0&quot;)\n // -&gt; Ok(SemVer(major: 1, minor; 0, patch: 0, pre: &quot;rc0&quot;, build: &quot;&quot;))\n \n\n \n parse_loosely(&quot;v1..3&quot;)\n // -&gt; Ok(SemVer(major: 1, minor; 0, patch: 3, pre: &quot;&quot;, build: &quot;&quot;))\n \n\n \n parse_loosely(&quot;v1.2+2024~05~05&quot;)\n // -&gt; Ok(SemVer(major: 1, minor; 2, patch: 0, pre: &quot;&quot;, build: &quot;v1.2+2024~05~05&quot;))\n \n\nSynonyms:\ngleamsver.parse_loosely\ngleamsver parse_loosely","url":"gleamsver.html#parse_loosely"},{"doc":"gleamsver","title":"string_from_parsing_error","content":"pub fn string_from_parsing_error(\n  error: SemVerParseError,\n) -&gt; String\n Returns the inner `String` from any [`SemVerParseError`](#SemVerParseError) type variant.\n\n This is equivalent to simply using `the_error.msg`.\n\n ## Examples\n\n \n string_from_parsing_error(EmptyInput(&quot;Input SemVer string is empty.&quot;))\n // -&gt; &quot;Input SemVer string is empty.&quot;\n \n\nSynonyms:\ngleamsver.string_from_parsing_error\ngleamsver string_from_parsing_error","url":"gleamsver.html#string_from_parsing_error"},{"doc":"gleamsver","title":"to_string","content":"pub fn to_string(ver: SemVer) -&gt; String\n Converts a [`SemVer`](#SemVer) into a `String` as defined on\n [semver.org](https://semver.org).\n\n ## Examples\n\n \n to_string(SemVer(1, 2, 3, &quot;rc0&quot;, &quot;20240505&quot;))\n // -&gt; &quot;1.2.3-rc0+20240505&quot;\n `\n\n Both the Pre-release (&quot;-rc0&quot;) and Build (&quot;+20240505&quot;) parts are optional:\n\n \n to_string(SemVer(1, 2, 3, &quot;rc0&quot;, &quot;&quot;))\n // -&gt; &quot;1.2.3-rc0&quot;\n `\n\n \n to_string(SemVer(1, 2, 3, &quot;&quot;, &quot;20240505&quot;))\n // -&gt; &quot;1.2.3+20240505&quot;\n `\n\nSynonyms:\ngleamsver.to_string\ngleamsver to_string","url":"gleamsver.html#to_string"},{"doc":"gleamsver","title":"to_string_concise","content":"pub fn to_string_concise(ver: SemVer) -&gt; String\n Converts a [`SemVer`](#SemVer) into a `String`\n as defined on [semver.org](https://semver.org).\n Will omit the `Minor.Patch` (second and third parts) if they are `0`.\n\n Although its output will **not** be re-parseable using [`parse`](#parse),\n it is still compatible with [`parse_loosely`](#parse_loosely).\n\n ## Examples\n\n \n to_string_concise(SemVer(1, 0, 0, &quot;rc0&quot;, &quot;20240505&quot;))\n // -&gt; &quot;1-rc0+20240505&quot;\n `\n\n \n to_string_concise(SemVer(1, 2, 0, &quot;rc0&quot;, &quot;20240505&quot;))\n // -&gt; &quot;1.2-rc0+20240505&quot;\n `\n\nSynonyms:\ngleamsver.to_string_concise\ngleamsver to_string_concise","url":"gleamsver.html#to_string_concise"},{"doc":"gleamsver","title":"gleamsver","content":" Gleam utilities for parsing, comparing, and encoding SemVer versions.\n\n This package aims to respect the specifications of the Semantic\n Versioning 2.0.0 standard as described on [semver.org](https://semver.org).\n\n ```gleam\n import gleam/io\n import gleamsver\n\n fn compress_message(message: String) -&gt; String {\n   message &lt;&gt; &quot;, but compressed ;)&quot;\n }\n\n pub fn main() {\n   // Parse correct SemVer 2.0.0 strings using `parse()`:\n   let assert Ok(server_version_with_compression) = gleamsver.parse(&quot;1.3.7-rc0&quot;)\n   io.debug(server_version_with_compression)  // SemVer(1, 3, 7, &quot;rc0&quot;, &quot;&quot;)\n\n   // Parse loose SemVer strings using `parse_loosely()`:\n   let assert Ok(current_server_version) = gleamsver.parse_loosely(&quot;v1.4&quot;)\n\n   // Convert back to SemVer strings using `to_string()`:\n   let uncompressed_message =\n     &quot;Hello, server version &quot; &lt;&gt; gleamsver.to_string(current_server_version)\n\n   let message = {\n     // Guard against version mismatches using `guard_version_*()` functions:\n     use &lt;- gleamsver.guard_version_compatible(\n       version: server_version_with_compression,\n       compatible_with: current_server_version,\n       else_return: uncompressed_message,\n     )\n\n     // Compression will only occur if the above guard succeeds:\n     compress_message(uncompressed_message)\n   }\n\n   // Prints &quot;Hello, server version 1.4.0, but compressed ;)&quot;\n   io.println(message)\n }\n ```","url":"gleamsver.html"}]);